==> sentry-dingding-maxbon-1.0.3.tar.gz: sentry-dingding-maxbon-1.0.3/src/sentry_dingding/plugin.py <==
# coding: utf-8

import json

import requests
from sentry.plugins.bases.notify import NotificationPlugin

import sentry_dingding
from .forms import DingDingOptionsForm

DingTalk_API = "https://oapi.dingtalk.com/robot/send?access_token={token}"


class DingDingPlugin(NotificationPlugin):
    """
    Sentry plugin to send error counts to DingDing.
    """
    author = 'maxbon'
    author_url = 'https://github.com/jacksnowfuck/sentry-dingding-maxbon'
    version = sentry_dingding.VERSION
    description = 'Send error counts to DingDing.'
    resource_links = [
        ('Source', 'https://github.com/jacksnowfuck/sentry-dingding-maxbon'),
        ('Bug Tracker', 'https://github.com/jacksnowfuck/sentry-dingding-maxbon/issues'),
        ('README', 'https://github.com/jacksnowfuck/sentry-dingding-maxbon/blob/master/README.md'),
    ]

    slug = 'DingDing4maxbon'
    title = 'DingDing4maxbon'
    conf_key = slug
    conf_title = title
    project_conf_form = DingDingOptionsForm

    def is_configured(self, project):
        """
        Check if plugin is configured.
        """
        return bool(self.get_option('access_token', project))

    def notify_users(self, group, event, *args, **kwargs):
        if self.should_notify(group, event):
            self.logger.info('send msg to dingtalk robot yes')
            self.post_process(group, event, *args, **kwargs)
        else:
            self.logger.info('send msg to dingtalk robot no')
            return

    def post_process(self, group, event, *args, **kwargs):
        """
        Process error.
        """
        if not self.is_configured(group.project):
            return

        if group.is_ignored():
            return

        access_token = self.get_option('access_token', group.project)
        send_url = DingTalk_API.format(token=access_token)
        title = u'【%s】【%s】的项目异常' % (event.get_tag("level"), event.project.slug)

        data = {
            "msgtype": "markdown",
            "markdown": {
                "title": title,
                "text": u"#### {title} \n\n > {message} \n\n > {environment} \n\n [详细信息]({url})".format(
                    title=title,
                    message=event.title or event.message,
                    #release=event.get_tag("release"),
                    environment=event.get_tag("environment"),
                    url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
                )
            }
        }
        requests.post(
            url=send_url,
            headers={"Content-Type": "application/json"},
            data=json.dumps(data).encode("utf-8")
        )

==> sentry-dingding-maxbon-1.0.4.tar.gz: sentry-dingding-maxbon-1.0.4/src/sentry_dingding/plugin.py <==
# coding: utf-8

import json

import requests
from sentry.plugins.bases.notify import NotificationPlugin

import sentry_dingding
from .forms import DingDingOptionsForm

DingTalk_API = "https://oapi.dingtalk.com/robot/send?access_token={token}"


class DingDingPlugin(NotificationPlugin):
    """
    Sentry plugin to send error counts to DingDing.
    """
    author = 'maxbon'
    author_url = 'https://github.com/jacksnowfuck/sentry-dingding-maxbon'
    version = sentry_dingding.VERSION
    description = 'Send error counts to DingDing.'
    resource_links = [
        ('Source', 'https://github.com/jacksnowfuck/sentry-dingding-maxbon'),
        ('Bug Tracker', 'https://github.com/jacksnowfuck/sentry-dingding-maxbon/issues'),
        ('README', 'https://github.com/jacksnowfuck/sentry-dingding-maxbon/blob/master/README.md'),
    ]

    slug = 'DingDing4maxbon'
    title = 'DingDing4maxbon'
    conf_key = slug
    conf_title = title
    project_conf_form = DingDingOptionsForm

    def is_configured(self, project):
        """
        Check if plugin is configured.
        """
        return bool(self.get_option('access_token', project))

    def notify_users(self, group, event, triggering_rules, fail_silently=False, *args, **kwargs):
        if self.should_notify(group, event):
            self.logger.info('send msg to dingtalk robot yes')
            self.post_process(group, event, triggering_rules, *args, **kwargs)
        else:
            self.logger.info('send msg to dingtalk robot no')
            return

    def post_process(self, group, event, triggering_rules, *args, **kwargs):
        """
        Process error.
        """
        if not self.is_configured(group.project):
            return

        if group.is_ignored():
            return

        access_token = self.get_option('access_token', group.project)
        send_url = DingTalk_API.format(token=access_token)
        title = u'【%s】【%s】的项目异常' % (event.get_tag("level"), event.project.slug)

        data = {
            "msgtype": "markdown",
            "markdown": {
                "title": title,
                "text": u"#### {title} \n\n > {message} \n\n > {environment} \n\n [详细信息]({url})".format(
                    title=title,
                    message=event.title or event.message,
                    triggering_rules=triggering_rules,
                    #release=event.get_tag("release"),
                    environment=event.get_tag("environment"),
                    url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
                )
            }
        }
        requests.post(
            url=send_url,
            headers={"Content-Type": "application/json"},
            data=json.dumps(data).encode("utf-8")
        )
